@@ -12,10 +12,10 @@ from PyQt5.QtWidgets import (QApplication, QAction, QToolBar,
                              QScrollArea, QGridLayout, QGroupBox,
                              QFileDialog, QSizePolicy)
 from ..backend import BinaryFile
-from ..backend.inputOutput import savePython, plot
+from ..backend.inputOutput import plot
 from ..backend.util import label
 from .view.sections import PrimaryData, TextMetaData, Unidentified
-from .view.utils import MENU_TREE, DTYPE_TO_SECTION_TITLE, createVariableNames
+from .view.utils import MENU_TREE, DTYPE_TO_COLOR, createVariableNames
 from .view.comms import  Communicate
 
 class MainWindow(QMainWindow):
@@ -61,7 +61,7 @@ class MainWindow(QMainWindow):
     rightSpacer.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
 
     loadIcon = QIcon("pymarble/frontend/static/images/load_file.png")
-    self.loadAction = QAction(loadIcon, "Load file", self)
+    self.loadAction = QAction(loadIcon, "load file", self)
     self.loadAction.triggered.connect(self.handleLoad)
     toolbar.addAction(self.loadAction)
 
@@ -72,14 +72,14 @@ class MainWindow(QMainWindow):
     toolbar.addWidget(leftSpacer)
 
     filterIcon = QIcon("pymarble/frontend/static/images/filter.png")
-    self.filterAction = QAction(filterIcon, "Filter Data", self)
+    self.filterAction = QAction(filterIcon, "filter data", self)
     self.filterAction.triggered.connect(self.drawView)
     self.filterAction.setCheckable(True)
     self.filterAction.setVisible(False)
     toolbar.addAction(self.filterAction)
 
     saveIcon = QIcon("pymarble/frontend/static/images/save.jpeg")
-    self.saveAction = QAction(saveIcon, "Save form", self)
+    self.saveAction = QAction(saveIcon, "save form", self)
     self.saveAction.triggered.connect(self.handleSave)
     self.saveAction.setEnabled(False)
     toolbar.addAction(self.saveAction)
@@ -146,7 +146,7 @@ class MainWindow(QMainWindow):
     '''
     Method that defines the view to be displayed while user loads a file to the application
     '''
-    self.loadedFileIndicator.setText("Please select a file and wait a couple of minutes for the processing to complete.")
+    self.loadedFileIndicator.setText("please select a file and wait a couple of minutes for the processing to complete.")
     self.loadedFileIndicator.setVisible(True)
     self.drawView()
 
@@ -154,7 +154,7 @@ class MainWindow(QMainWindow):
     # NOTE homeDir = str(Path.home())
     # TODO decide where the file dialog box should start. Now it is hard-coded to start at examples for testing ease.
     dialogBox = QFileDialog()
-    fName = dialogBox.getOpenFileName(self, "Select file to load", f"{currentDir}/tests/examples/")
+    fName = dialogBox.getOpenFileName(self, "select file to load", f"{currentDir}/tests/examples/")
 
     # NOTE since fName = ('','') in case dialog is closed via cancel.
     if fName[0] != '':
@@ -180,6 +180,7 @@ class MainWindow(QMainWindow):
     '''
     Method that saves input obtained via user interaction, to a python file
     '''
+    # TODO remove this when functionality is stable and application is version published
     self.backend.printList()
     self.backend.savePython()
     self.saveAction.setEnabled(False)
@@ -206,7 +207,9 @@ class MainWindow(QMainWindow):
 
       if sectionClass := self._DTYPE_TO_UICLASS.get(props["data"].dType):
         section = sectionClass(props).createWidget()
-        sectionWidget = QGroupBox(f"{idx + 1}. {DTYPE_TO_SECTION_TITLE[self.backend.content[sec_start].dType]}")
+        sectionWidget = QGroupBox()
+        sectionStyleSheet = '''QGroupBox {{ background-color: {color}; border: 0px; border-left: 20px solid grey}}'''.format(color=DTYPE_TO_COLOR.get(props['data'].dType))
+        sectionWidget.setStyleSheet(sectionStyleSheet)
         sectionWidget.setLayout(section)
         sectionWidget.setVisible(False if (self.filterAction.isChecked() and self.backend.content[sec_start].dType in ('b', 'B')) else True)
         self.containerLayout.addWidget(sectionWidget)
@@ -229,34 +232,13 @@ class MainWindow(QMainWindow):
     Method to identify and update a sections key-value with user input
     '''
     section = self.backend.content[currStart]
-    # setData in Section definition requires data being passed in following format
-    # sectionData = f'{section.length}|{section.dType}|{section.key}|{section.unit}|{section.link}|{section.dClass}|{section.count}|{section.shape}|{section.prob}|{section.entropy}|{section.important}|{section.value}'
-    # ! If you change the length, don't give the shape as they have to correspond at it is best to let backend figure out the shape
-
-    # The following works
     sectionData = repr(section)
-
-    # TODO when above is supplied as data to label,
-    # which subsequently passes it on to setData,
-    # this functionality breaks. Fix required
-
-    # print('Section to be deleted:', currStart, self.backend.content[currStart])
-    # deleting section with current value
-    # del section
-    # del self.backend.content[currStart]
-
-    # creating the new section with updated values
-    print('Create new section for:', newStart, sectionData)
     sectionData = '|'.join(sectionData.split('|')[:6])
-    print('  after cropping things that should not be updated:', sectionData)
-
     label(self.backend, newStart, sectionData)
-    print("AFTER LABEL")
+    # TODO remove this when functionality is stable and application is version published
     self.backend.printList()
-    #print(f"updated backend old start > {currStart}, new start > {newStart}:", self.backend.content)
 
     self.drawView()
-    self.saveAction.setEnabled(True)
 
   # Create an option to be displayed on menu bar
   def createMenuOption(self, menu, option):
