@@ -6,7 +6,7 @@ from PyQt5.QtWidgets import (QLabel, QPushButton,
                              QGridLayout, QComboBox, QLineEdit,
                              QRadioButton, QCheckBox,
                              QHBoxLayout, QWidget, QSpinBox,
-                            )
+                             )
 from PyQt5.QtGui import QIcon
 from .utils import createStyleSheet, COLOR_KEYS, PROBABILITY_MAP
 from .comms import Communicate
@@ -17,9 +17,7 @@ class UISection:
   from the user loaded file, via the backend run
   '''
   def __init__(self, props):
-    self.idx = props["id"]
-    self.secKey = props["secKey"]
-
+    # content stored in backend
     self.key = props["data"].key
     self.unit = props["data"].unit
     self.prob = props["data"].prob
@@ -32,8 +30,10 @@ class UISection:
     self.count = props["data"].count
     self.shape = props["data"].shape
     self.entropy = props["data"].entropy
+    # other
+    self.idx = props["id"]
+    self.secKey = props["secKey"]
     self.updatedStart = self.secKey
-
     self.communicate = props["view"]
 
 
@@ -41,11 +41,20 @@ class UISection:
     '''
     UI method that creates a checkbox for user to flag a section as important
     '''
-    importantCheck = QCheckBox("Important")
+    importantCheck = QCheckBox("important")
     importantCheck.setChecked(self.imp)
     importantCheck.stateChanged.connect(lambda: self.handleValueChange(importantCheck.isChecked(), "important"))
     return importantCheck
 
+  def createKeyValueBox(self, keyWidget, valueWidget):
+    '''
+    UI method to create a key-value UI pair of widgets
+    '''
+    layout = QHBoxLayout()
+    layout.addWidget(keyWidget)
+    layout.addWidget(valueWidget)
+    return layout
+
   def createEditButton(self, editForm):
     '''
     UI method that creates the edit button for each section
@@ -75,19 +84,15 @@ class UISection:
 
     def sectionSaveButton(layout):
       saveIcon = QIcon("pymarble/frontend/static/images/save_sec.jpg")
-      saveButton = QPushButton(saveIcon, "Save")
+      saveButton = QPushButton(saveIcon, "save")
       saveButton.clicked.connect(lambda: self.handleSectionUpdate())
-      layout.addWidget(saveButton)
+      layout.addWidget(saveButton, 1, (layout.columnCount() +1))
 
     def inputFor(data, key, title, layout, dtype=None, placeholder=None):
       '''
       UI Function to create custom textfield component
       '''
       inputLabel = QLabel(f"&{title}:  ")
-      # TODO the check to differentiate between numeric and non-numeric values is high risk
-      # went this way because some start values are of type numpy.int64.
-      # need  to clarify why and get this fixed - both logic and implementation
-
       if type(data) is int:
         inputField = QSpinBox()
         inputField.setMaximum(100000)
@@ -102,20 +107,19 @@ class UISection:
         inputField = QLineEdit()
         inputField.setPlaceholderText(placeholder)
         inputField.setText(data)
-
       inputField.textChanged.connect(lambda: self.handleValueChange(inputField.text(), key))
       inputLabel.setBuddy(inputField)
-      layout.addWidget(inputLabel)
-      layout.addWidget(inputField)
+      layout.addLayout(self.createKeyValueBox(inputLabel, inputField), 1, (layout.columnCount() + 1))
 
     form = QWidget()
-    formLayout = QHBoxLayout()
+    formLayout = QGridLayout()
+    formLayout.setHorizontalSpacing(80)
 
-    inputFor(int(self.secKey), "start", "Start", formLayout, dtype=self.dType)
-    inputFor(int(self.length), "length", "Length", formLayout, dtype=self.dType)
-    inputFor(self.dType, "dType", "Data type", formLayout, placeholder="Enter data type")
-    inputFor(self.link, "link", "Link", formLayout, placeholder="Enter link")
-    inputFor(self.dClass, "dClass", "Data class", formLayout, placeholder="Enter length")
+    inputFor(int(self.secKey), "start", "start", formLayout, dtype=self.dType)
+    inputFor(int(self.length), "length", "length", formLayout, dtype=self.dType)
+    inputFor(self.dType, "dType", "data type", formLayout, placeholder="enter data type")
+    inputFor(self.link, "link", "link", formLayout, placeholder="enter link")
+    inputFor(self.dClass, "dClass", "data class", formLayout, placeholder="enter length")
     sectionSaveButton(formLayout)
 
     form.setLayout(formLayout)
@@ -128,7 +132,7 @@ class UISection:
     certaintyBox = QWidget()
     certaintyLayout = QHBoxLayout()
 
-    certaintyLabel = QLabel("Input certainty: ")
+    certaintyLabel = QLabel("input certainty:")
     radioRed = QRadioButton()
     radioRed.setStyleSheet(createStyleSheet(element='radio', props={"color": COLOR_KEYS["RED"]}))
     if int(self.prob) <= PROBABILITY_MAP[COLOR_KEYS["RED"]]:
@@ -195,28 +199,29 @@ class Unidentified(UISection):
     '''
     unidentifiedLayout = QGridLayout()
 
-    algoLabel = QLabel("&Algorithm: ")
+    algoLabel = QLabel("&algorithm:  ")
     self.algoDropdown = QComboBox()
     self.algoDropdown.addItems(["Algo option 01", "Algo option 02", "Algo option 03", "Algo option 04"])
     algoLabel.setBuddy(self.algoDropdown)
-    unidentifiedLayout.addWidget(algoLabel, 1, 0, Qt.AlignmentFlag.AlignRight)
-    unidentifiedLayout.addWidget(self.algoDropdown, 1, 1, Qt.AlignmentFlag.AlignLeft)
-    identifyIcon = QIcon("pymarble/frontend/static/images/identify.jpg")
-    identifyButton = QPushButton(identifyIcon, "Identify")
-    identifyButton.clicked.connect(lambda: self.handleIdentify())
-    unidentifiedLayout.addWidget(identifyButton, 1, 2, Qt.AlignmentFlag.AlignLeft)
+    unidentifiedLayout.addLayout(self.createKeyValueBox(algoLabel, self.algoDropdown), 1, 0, Qt.AlignmentFlag.AlignCenter)
 
-    unidentifiedLayout.setColumnStretch(3, 1)
+    identifyIcon = QIcon("pymarble/frontend/static/images/identify.jpg")
+    identifyButton = QPushButton(identifyIcon, "identify")
+    identifyButton.clicked.connect(lambda: self.handleIdentify())
+    unidentifiedLayout.addWidget(identifyButton, 1, 1, Qt.AlignmentFlag.AlignCenter)
+
+    unidentifiedLayout.setColumnStretch(2, 1)
 
     flag = self.flagImportant()
     # TODO enable button when functionality is clear, and handle data capture
     flag.setDisabled(True)
     editForm = self.createEditForm()
     editForm.setVisible(False)
-    unidentifiedLayout.addWidget(flag, 1, 4, Qt.AlignmentFlag.AlignCenter)
-    unidentifiedLayout.addWidget(self.createEditButton(editForm), 1, 5, Qt.AlignmentFlag.AlignCenter)
-    unidentifiedLayout.addWidget(editForm, 2, 0, 1, 5, Qt. AlignmentFlag.AlignLeft)
+    unidentifiedLayout.addWidget(flag, 1, 3, Qt.AlignmentFlag.AlignCenter)
+    unidentifiedLayout.addWidget(self.createEditButton(editForm), 1, 4, Qt.AlignmentFlag.AlignCenter)
+    unidentifiedLayout.addWidget(editForm, 2, 0, 1, 4, Qt. AlignmentFlag.AlignLeft)
 
+    unidentifiedLayout.setHorizontalSpacing(80)
     return unidentifiedLayout
 
   def handleIdentify(self):
@@ -243,33 +248,33 @@ class TextMetaData(UISection):
     '''
     textMetadataLayout = QGridLayout()
 
-    keyLabel = QLabel("&Key:  ")
+    keyLabel = QLabel("&key:  ")
     keyInput = QLineEdit()
     keyInput.textChanged.connect(lambda: self.handleValueChange(keyInput.text(), "key"))
-    keyInput.setPlaceholderText('Enter key for value')
+    keyInput.setPlaceholderText('enter key for value')
     keyInput.setText(self.key)
     keyLabel.setBuddy(keyInput)
-    textMetadataLayout.addWidget(keyLabel, 1, 0, Qt.AlignmentFlag.AlignRight)
-    textMetadataLayout.addWidget(keyInput, 1, 1, Qt.AlignmentFlag.AlignLeft)
+    textMetadataLayout.addLayout(self.createKeyValueBox(keyLabel, keyInput), 1, 0, Qt.AlignmentFlag.AlignCenter)
 
-    valueLabel = QLabel("&Value: ")
+    valueLabel = QLabel("&value:  ")
     sectionValue = QLabel(self.value)
     valueLabel.setBuddy(sectionValue)
-    textMetadataLayout.addWidget(valueLabel, 1, 2, Qt.AlignmentFlag.AlignRight)
-    textMetadataLayout.addWidget(sectionValue, 1, 3, Qt.AlignmentFlag.AlignLeft)
+    textMetadataLayout.addLayout(self.createKeyValueBox(valueLabel, sectionValue), 1, 1, Qt.AlignmentFlag.AlignCenter)
 
-    textMetadataLayout.setColumnStretch(4, 1)
+
+    textMetadataLayout.setColumnStretch(2, 1)
 
     certainty = self.showCertainty()
-    textMetadataLayout.addWidget(certainty, 1, 5, 1, 1, Qt.AlignmentFlag.AlignHCenter)
+    textMetadataLayout.addWidget(certainty, 1, 3, 1, 1, Qt.AlignmentFlag.AlignHCenter)
 
     flag = self.flagImportant()
     editForm = self.createEditForm()
     editForm.setVisible(False)
-    textMetadataLayout.addWidget(flag, 1, 6, Qt.AlignmentFlag.AlignCenter)
-    textMetadataLayout.addWidget(self.createEditButton(editForm), 1, 7, Qt.AlignmentFlag.AlignCenter)
-    textMetadataLayout.addWidget(editForm, 2, 0, 1, 6, Qt. AlignmentFlag.AlignLeft)
+    textMetadataLayout.addWidget(flag, 1, 4, Qt.AlignmentFlag.AlignCenter)
+    textMetadataLayout.addWidget(self.createEditButton(editForm), 1, 5, Qt.AlignmentFlag.AlignCenter)
+    textMetadataLayout.addWidget(editForm, 2, 0, 1, 4, Qt. AlignmentFlag.AlignLeft)
 
+    textMetadataLayout.setHorizontalSpacing(80)
     return textMetadataLayout
 
 class PrimaryData(UISection):
@@ -289,47 +294,53 @@ class PrimaryData(UISection):
     '''
     primaryDataLayout = QGridLayout()
 
-    keyLabel = QLabel("&Key:  ")
+    keyLabel = QLabel("&key:  ")
     keyInput = QLineEdit()
     keyInput.textChanged.connect(lambda: self.handleValueChange(keyInput.text(), "key"))
-    keyInput.setPlaceholderText('Enter key for value')
+    keyInput.setPlaceholderText('enter key for value')
     keyInput.setText(self.key)
     keyLabel.setBuddy(keyInput)
-    primaryDataLayout.addWidget(keyLabel, 1, 0, Qt.AlignmentFlag.AlignRight)
-    primaryDataLayout.addWidget(keyInput, 1, 1, Qt.AlignmentFlag.AlignLeft)
+    primaryDataLayout.addLayout(self.createKeyValueBox(keyLabel, keyInput), 1, 0, Qt.AlignmentFlag.AlignCenter)
 
-    unitLabel = QLabel("&Unit: ")
+    unitLabel = QLabel("&unit:  ")
     unitInput = QLineEdit()
     unitInput.textChanged.connect(lambda: self.handleValueChange(unitInput.text(), "unit"))
-    unitInput.setPlaceholderText('Enter unit for key')
+    unitInput.setPlaceholderText('enter unit for key')
     unitInput.setText(self.unit)
     unitLabel.setBuddy(unitInput)
-    primaryDataLayout.addWidget(unitLabel, 1, 2, Qt.AlignmentFlag.AlignRight)
-    primaryDataLayout.addWidget(unitInput, 1, 3, Qt.AlignmentFlag.AlignLeft)
+    primaryDataLayout.addLayout(self.createKeyValueBox(unitLabel, unitInput), 1, 1, Qt.AlignmentFlag.AlignCenter)
 
-    valueLabel = QLabel("&Value: ")
+
+    valueLabel = QLabel("&value:  ")
     sectionValue = QLabel(self.value)
     valueLabel.setBuddy(sectionValue)
-    primaryDataLayout.addWidget(valueLabel, 1, 4, Qt.AlignmentFlag.AlignRight)
-    primaryDataLayout.addWidget(sectionValue, 1, 5, Qt.AlignmentFlag.AlignLeft)
+    primaryDataLayout.addLayout(self.createKeyValueBox(valueLabel, sectionValue), 1, 2, Qt.AlignmentFlag.AlignCenter)
 
     drawIcon = QIcon("pymarble/frontend/static/images/draw.jpeg")
-    drawButton = QPushButton(drawIcon, "Plot")
+    drawButton = QPushButton(drawIcon, "plot")
     drawButton.clicked.connect(lambda: self.handleDraw())
-    primaryDataLayout.addWidget(drawButton, 1, 6, Qt.AlignmentFlag.AlignCenter)
+    primaryDataLayout.addWidget(drawButton, 1, 3, Qt.AlignmentFlag.AlignCenter)
 
-    primaryDataLayout.setColumnStretch(7, 1)
+    primaryDataLayout.setColumnStretch(4, 1)
+
+    if len(self.count) == 0:
+      warningIcon = QIcon("pymarble/frontend/static/images/warning.png")
+      warningButton = QPushButton(warningIcon,'')
+      warningButton.setFlat(True)
+      warningButton.setToolTip("the corresponding length is not found in file")
+      primaryDataLayout.addWidget(warningButton, 1, 5, Qt.AlignmentFlag.AlignRight)
 
     certainty = self.showCertainty()
-    primaryDataLayout.addWidget(certainty, 1, 8, 1, 2, Qt.AlignmentFlag.AlignCenter)
+    primaryDataLayout.addWidget(certainty, 1, 6, 1, 2, Qt.AlignmentFlag.AlignCenter)
 
     flag = self.flagImportant()
     editForm = self.createEditForm()
     editForm.setVisible(False)
-    primaryDataLayout.addWidget(flag, 1, 10, 1, 1, Qt.AlignmentFlag.AlignVCenter)
-    primaryDataLayout.addWidget(self.createEditButton(editForm), 1, 11, 1, 1, Qt.AlignmentFlag.AlignVCenter)
-    primaryDataLayout.addWidget(editForm, 2, 0, 1, 10, Qt. AlignmentFlag.AlignLeft)
+    primaryDataLayout.addWidget(flag, 1, 8, 1, 1, Qt.AlignmentFlag.AlignVCenter)
+    primaryDataLayout.addWidget(self.createEditButton(editForm), 1, 9, 1, 1, Qt.AlignmentFlag.AlignVCenter)
+    primaryDataLayout.addWidget(editForm, 2, 0, 1, 8, Qt. AlignmentFlag.AlignLeft)
 
+    primaryDataLayout.setHorizontalSpacing(80)
     return primaryDataLayout
 
   def handleDraw(self):
