@@ -60,7 +60,7 @@ def main():
     printHelp()
 
   else:
-    fBIN = BinaryFile(sys.argv[1])
+    fBIN = BinaryFile(sys.argv[1], verbose=1)
     numCommands = 99999 if len(sys.argv)==2 else len(sys.argv[2].split(';'))
     for idx in range(numCommands):
       if len(sys.argv)==2:
@@ -72,7 +72,7 @@ def main():
       if command.startswith('s'):
         fBIN.findStreak(command[1],int(command.split()[1], 0))
       elif command.startswith('m'):
-        methodOrder = 'x_z_a_p' if len(command.split())==1 else command.split()[1]
+        methodOrder = 'x_z_p_a' if len(command.split())==1 else command.split()[1]
         fBIN.automatic(methodOrder)
       elif command.startswith('z'):
         fBIN.entropy()
@@ -115,7 +115,7 @@ def main():
         fBIN.addNote()
       elif command=='x mode':
         if fBIN.printMode=='dec':
-          fBIN.printMode='bin'
+          fBIN.printMode='hex'
         else:
           fBIN.printMode='dec'
       elif command=='ot':
